@@ -19,7 +19,7 @@
 @CREATED    : Greg Ward, 1996/07/25-28
 @MODIFIED   : Jan 1997
               Jun 1997
-@VERSION    : $Id: lex_auxiliary.c 8964 2010-09-18 14:34:16Z ambs $
+@VERSION    : $Id$
 @COPYRIGHT  : Copyright (c) 1996-99 by Gregory P. Ward.  All rights reserved.
 
               This file is part of the btparse library.  This library is
@@ -210,7 +210,7 @@ void alloc_lex_buffer (int size)
    {
       zztoktext = (char *) malloc (size * sizeof (char));
       memset (zztoktext, 0, size);
-      zzlextext = zztoktext;
+      zzlextext = (unsigned char*)zztoktext;
       zzbufsize = size;
    }
 } /* alloc_lex_buffer() */
@@ -253,7 +253,7 @@ realloc_lex_buffer (int     size_increment,
    beg = zzbegexpr - zzlextext;
    end = zzendexpr - zzlextext;
    next = *nextpos - (unsigned char *) zzlextext;
-   zzlextext = zztoktext;
+   zzlextext = (unsigned char*)zztoktext;
 
    if (lastpos != NULL)
       *lastpos = zzlextext+zzbufsize-1;
@@ -431,7 +431,7 @@ void at_sign (void)
 
 void toplevel_junk (void)
 {
-   JunkCount += strlen (zzlextext);
+    JunkCount += strlen ((const char*)zzlextext);
    zzskip ();
 }
 
@@ -449,7 +449,7 @@ void name (void)
       }
       case after_at: 
       {
-         char * etype = zzlextext;
+         char * etype = (char*)zzlextext;
          EntryState = after_type;
 
          if (strcasecmp (etype, "comment") == 0)
@@ -660,7 +660,7 @@ void end_string (char end_char)
 
    if (EntryState == in_comment)
    {
-      int   len = strlen (zzlextext);
+       int   len = strlen ((const char*)zzlextext);
 
       /* 
        * ARG! no, this is wrong -- what if unbalanced braces in the string 
@@ -859,14 +859,25 @@ void check_runaway_string (void)
       zzline++;
    }
 
-   /* standardize whitespace (convert all to space) but don't accept ascii 160 
-      as space which most broken ctype.h do as this breaks lots of Unicode things */
-
-   len = strlen (zzbegexpr);
+   len = strlen ((const char*)zzbegexpr);
    for (i = 0; i < len; i++)
    {
-       if (isspace (zzbegexpr[i]) && zzbegexpr[i] != 160)
-           zzbegexpr[i] = ' ';
+     /* standardise whitespace (convert all to space). We are not using
+        ctype isspace() as this is unreliable on many modern systems which
+        try to be clever and count as spaces some special things like ASCII
+        160 (non-breaking space) and 133 (horizontal ellipsis). This breaks
+        lots of Unicode chars as they pass through here. What we mean by
+        "whitespace" is nothing so clever, it's just the usual few ASCII
+        chars that should appear as normal spaces.
+     */
+
+     /* if (isspace (zzbegexpr[i])) */
+     if (zzbegexpr[i] == 9 ||
+         zzbegexpr[i] == 10 || 
+         zzbegexpr[i] == 11 || 
+         zzbegexpr[i] == 12 || 
+         zzbegexpr[i] == 13)
+     zzbegexpr[i] = ' ';
    }
    
 
