@@ -24,7 +24,7 @@ use strict;
 use Carp;
 
 use vars qw'$VERSION';
-$VERSION = 0.1;
+$VERSION = 0.73;
 
 use Text::BibTeX ('check_class');
 
@@ -869,7 +869,9 @@ sub get_options
 
 package Text::BibTeX::StructuredEntry;
 use strict;
-use vars qw(@ISA);
+use vars qw(@ISA $VERSION);
+$VERSION = 0.73;
+
 use Carp;
 
 @ISA = ('Text::BibTeX::Entry');
