@@ -18,11 +18,11 @@
 package Text::BibTeX::Value;
 
 use strict;
-use UNIVERSAL 'isa';
+use Scalar::Util 'blessed';
 use Carp;
 
 use vars qw'$VERSION';
-$VERSION = 0.1;
+$VERSION = 0.73;
 
 =head1 NAME
 
@@ -206,7 +206,7 @@ sub new
          if ref $sval eq 'ARRAY' && @$sval == 2;
       croak "simple value is neither a two-element array ref " .
             "nor a Text::BibTeX::SimpleValue object"
-         unless isa ($sval, 'Text::BibTeX::SimpleValue');
+         unless blessed($sval) && $sval->isa('Text::BibTeX::SimpleValue');
       push (@$self, $sval);
    }
 
@@ -244,6 +244,10 @@ use strict;
 use Carp;
 use Text::BibTeX qw(:nodetypes);
 
+use vars qw($VERSION);
+$VERSION = '0.73';
+
+
 =head2 Text::BibTeX::SimpleValue methods
 
 =over
